summaryrefslogtreecommitdiff
path: root/src/include/connection.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/connection.h')
-rw-r--r--src/include/connection.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/include/connection.h b/src/include/connection.h
index d9300b319fa..c9f1bda9d10 100644
--- a/src/include/connection.h
+++ b/src/include/connection.h
@@ -256,9 +256,9 @@ struct __wt_connection_impl {
WT_LOG *log; /* Logging structure */
wt_off_t log_file_max; /* Log file max size */
const char *log_path; /* Logging path format */
- int log_recycle; /* Log file recycle configuration */
- /* Maximum recycled log files */
- uint32_t log_recycle_max;
+ int log_prepare; /* Log file prepare configuration */
+ /* Maximum prepared log files */
+ uint32_t log_prepared_max;
uint32_t txn_logsync; /* Log sync configuration */
WT_SESSION_IMPL *sweep_session; /* Handle sweep session */